# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ssc-common.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ssc-common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10ssc-common.proto\"#\n\x06SscUid\x12\x0b\n\x03low\x18\x01 \x02(\x06\x12\x0c\n\x04high\x18\x02 \x02(\x06\"@\n\x0fSscClientConfig\x12\x14\n\tprocessor\x18\x01 \x02(\x05:\x01\x31\x12\x17\n\x0csuspend_mode\x18\x02 \x02(\x05:\x01\x30\"O\n\x14SscClientRequestBody\x12\x0f\n\x07unknown\x18\x01 \x01(\x0c\x12\x0b\n\x03msg\x18\x02 \x01(\x0c\x12\x19\n\nis_passive\x18\x03 \x01(\x08:\x05\x66\x61lse\"\x82\x01\n\x10SscClientRequest\x12\x14\n\x03uid\x18\x01 \x02(\x0b\x32\x07.SscUid\x12\x0e\n\x06msg_id\x18\x02 \x02(\x07\x12 \n\x06\x63onfig\x18\x03 \x02(\x0b\x32\x10.SscClientConfig\x12&\n\x07request\x18\x04 \x02(\x0b\x32\x15.SscClientRequestBody\"G\n\x15SscClientResponseBody\x12\x0e\n\x06msg_id\x18\x01 \x02(\x07\x12\x11\n\ttimestamp\x18\x02 \x02(\x06\x12\x0b\n\x03msg\x18\x03 \x02(\x0c\"S\n\x11SscClientResponse\x12\x14\n\x03uid\x18\x01 \x02(\x0b\x32\x07.SscUid\x12(\n\x08response\x18\x02 \x03(\x0b\x32\x16.SscClientResponseBody\"(\n\x0eSscAttrRequest\x12\x16\n\x0e\x65nable_updates\x18\x02 \x01(\x08\"3\n\x11SscAttrValueArray\x12\x1e\n\x07\x65lement\x18\x01 \x03(\x0b\x32\r.SscAttrValue\"Y\n\x0cSscAttrValue\x12\x1d\n\x01\x61\x18\x01 \x01(\x0b\x32\x12.SscAttrValueArray\x12\t\n\x01s\x18\x02 \x01(\t\x12\t\n\x01\x66\x18\x03 \x01(\x02\x12\t\n\x01i\x18\x04 \x01(\x06\x12\t\n\x01\x62\x18\x05 \x01(\x08\"-\n\x11SscAttrArrayValue\x12\x18\n\x01v\x18\x01 \x03(\x0b\x32\r.SscAttrValue\">\n\x07SscAttr\x12\n\n\x02id\x18\x01 \x02(\x05\x12\'\n\x0bvalue_array\x18\x02 \x02(\x0b\x32\x12.SscAttrArrayValue\")\n\x0fSscAttrResponse\x12\x16\n\x04\x61ttr\x18\x01 \x03(\x0b\x32\x08.SscAttr\"-\n\x16SscEnableConfigRequest\x12\x13\n\x0bsample_rate\x18\x01 \x02(\x02\"6\n\x11SscConfigResponse\x12\x13\n\x0bsample_rate\x18\x01 \x01(\x02\x12\x0c\n\x04mode\x18\x05 \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ssc_common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SSCUID']._serialized_start=20
  _globals['_SSCUID']._serialized_end=55
  _globals['_SSCCLIENTCONFIG']._serialized_start=57
  _globals['_SSCCLIENTCONFIG']._serialized_end=121
  _globals['_SSCCLIENTREQUESTBODY']._serialized_start=123
  _globals['_SSCCLIENTREQUESTBODY']._serialized_end=202
  _globals['_SSCCLIENTREQUEST']._serialized_start=205
  _globals['_SSCCLIENTREQUEST']._serialized_end=335
  _globals['_SSCCLIENTRESPONSEBODY']._serialized_start=337
  _globals['_SSCCLIENTRESPONSEBODY']._serialized_end=408
  _globals['_SSCCLIENTRESPONSE']._serialized_start=410
  _globals['_SSCCLIENTRESPONSE']._serialized_end=493
  _globals['_SSCATTRREQUEST']._serialized_start=495
  _globals['_SSCATTRREQUEST']._serialized_end=535
  _globals['_SSCATTRVALUEARRAY']._serialized_start=537
  _globals['_SSCATTRVALUEARRAY']._serialized_end=588
  _globals['_SSCATTRVALUE']._serialized_start=590
  _globals['_SSCATTRVALUE']._serialized_end=679
  _globals['_SSCATTRARRAYVALUE']._serialized_start=681
  _globals['_SSCATTRARRAYVALUE']._serialized_end=726
  _globals['_SSCATTR']._serialized_start=728
  _globals['_SSCATTR']._serialized_end=790
  _globals['_SSCATTRRESPONSE']._serialized_start=792
  _globals['_SSCATTRRESPONSE']._serialized_end=833
  _globals['_SSCENABLECONFIGREQUEST']._serialized_start=835
  _globals['_SSCENABLECONFIGREQUEST']._serialized_end=880
  _globals['_SSCCONFIGRESPONSE']._serialized_start=882
  _globals['_SSCCONFIGRESPONSE']._serialized_end=936
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ssc-sensor-gyroscope.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ssc-sensor-gyroscope.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1assc-sensor-gyroscope.proto\":\n\x14SscGyroscopeResponse\x12\x10\n\x08velocity\x18\x01 \x03(\x02\x12\x10\n\x08\x61\x63\x63uracy\x18\x02 \x02(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ssc_sensor_gyroscope_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SSCGYROSCOPERESPONSE']._serialized_start=30
  _globals['_SSCGYROSCOPERESPONSE']._serialized_end=88
# @@protoc_insertion_point(module_scope)
